@@ -1,7 +1,7 @@
 package DBIx::DataModel::Meta::Source::Join;
 use strict;
 use warnings;
-use Params::Validate qw/ARRAYREF/;
+use Params::Validate qw/ARRAYREF HASHREF/;
 
 use parent "DBIx::DataModel::Meta::Source";
 
@@ -12,7 +12,9 @@ sub new {
   $class->_new_meta_source(
 
     # more spec for Params::Validate
-    { sqla_join_args => {type => ARRAYREF} },
+    { sqla_join_args     => {type => ARRAYREF},
+      db_table_by_source => {type => HASHREF},
+    },
 
     # method to call in schema for building @ISA
     'join_parent',
