@@ -3,7 +3,7 @@ package DBIx::DataModel::Schema::ResultAs::Yaml;
 #----------------------------------------------------------------------
 use warnings;
 use strict;
-use Carp::Clan        qw[^(DBIx::DataModel::|SQL::Abstract)];
+use DBIx::DataModel::Carp;
 use YAML::XS          qw[Dump];
 
 use parent 'DBIx::DataModel::Schema::ResultAs';
